@@ -61,6 +61,8 @@ sub run {
   $status->{repair_interval} //= 21600;
   $status->{repair_interval} -= int rand $status->{repair_interval} / 2;
 
+  # Reset event loop
+  Mojo::IOLoop->reset;
   local $SIG{CHLD} = sub { };
   local $SIG{INT}  = local $SIG{TERM} = sub { $self->{finished}++ };
   local $SIG{QUIT} = sub {
